pub struct PassiveManagedService { /* private fields */ }Expand description
Managed adapter for a passive Runtime resource with no owned worker.
Implementations
Sourceimpl PassiveManagedService
impl PassiveManagedService
Sourcepub fn new(descriptor: ServiceDescriptor) -> Self
pub fn new(descriptor: ServiceDescriptor) -> Self
Creates a passive service whose start transition produces Ready.